summaryrefslogtreecommitdiff
path: root/src/mongo/crypto/sha256_block.h
diff options
context:
space:
mode:
authorJason Piao <jason.piao@mongodb.com>2019-06-17 16:46:50 -0400
committerJason Piao <jason.piao@mongodb.com>2019-06-17 16:46:50 -0400
commite45441ca46ff35e5ff8d4ca6dbe159996c87d007 (patch)
tree636750bc31936d01fdf5b541a2c313cd944c18c3 /src/mongo/crypto/sha256_block.h
parent9382259ce8399ce75c17d517112ac9bab230b01d (diff)
downloadmongo-e45441ca46ff35e5ff8d4ca6dbe159996c87d007.tar.gz
SERVER-41440 Rename SHABlock to HashBlock
Diffstat (limited to 'src/mongo/crypto/sha256_block.h')
-rw-r--r--src/mongo/crypto/sha256_block.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/crypto/sha256_block.h b/src/mongo/crypto/sha256_block.h
index 7514e33bd82..e16ef5f2126 100644
--- a/src/mongo/crypto/sha256_block.h
+++ b/src/mongo/crypto/sha256_block.h
@@ -29,14 +29,14 @@
#pragma once
-#include "mongo/crypto/sha_block.h"
+#include "mongo/crypto/hash_block.h"
#include "mongo/util/make_array_type.h"
namespace mongo {
/**
* A Traits type for adapting SHABlock to sha256 hashes.
*/
struct SHA256BlockTraits {
using HashType = MakeArrayType<std::uint8_t, 32, SHA256BlockTraits>;
@@ -51,6 +51,6 @@ struct SHA256BlockTraits {
HashType* const output);
};
-using SHA256Block = SHABlock<SHA256BlockTraits>;
+using SHA256Block = HashBlock<SHA256BlockTraits>;
} // namespace mongo
@@ -29,14 +29,14 @@
namespace mongo {
/**
- * A Traits type for adapting SHABlock to sha256 hashes.
+ * A Traits type for adapting HashBlock to sha256 hashes.
*/
struct SHA256BlockTraits {